Class: FbGraph2::Edge
- Inherits:
-
Collection
- Object
- Array
- Collection
- FbGraph2::Edge
- Defined in:
- lib/fb_graph2/edge.rb,
lib/fb_graph2/edge/feed.rb,
lib/fb_graph2/edge/home.rb,
lib/fb_graph2/edge/books.rb,
lib/fb_graph2/edge/games.rb,
lib/fb_graph2/edge/likes.rb,
lib/fb_graph2/edge/links.rb,
lib/fb_graph2/edge/music.rb,
lib/fb_graph2/edge/posts.rb,
lib/fb_graph2/edge/albums.rb,
lib/fb_graph2/edge/events.rb,
lib/fb_graph2/edge/family.rb,
lib/fb_graph2/edge/groups.rb,
lib/fb_graph2/edge/movies.rb,
lib/fb_graph2/edge/tagged.rb,
lib/fb_graph2/edge/friends.rb,
lib/fb_graph2/edge/accounts.rb,
lib/fb_graph2/edge/statuses.rb,
lib/fb_graph2/edge/interests.rb,
lib/fb_graph2/edge/activities.rb,
lib/fb_graph2/edge/television.rb,
lib/fb_graph2/edge/achievements.rb,
lib/fb_graph2/edge/friend_lists.rb
Defined Under Namespace
Modules: Accounts, Achievements, Activities, Albums, Books, Events, Family, Feed, FriendLists, Friends, Games, Groups, Home, Interests, Likes, Links, Movies, Music, Posts, Statuses, Tagged, Television
Instance Attribute Summary collapse
-
#collection ⇒ Object
Returns the value of attribute collection.
-
#edge ⇒ Object
Returns the value of attribute edge.
-
#options ⇒ Object
Returns the value of attribute options.
-
#owner ⇒ Object
Returns the value of attribute owner.
-
#params ⇒ Object
Returns the value of attribute params.
Attributes inherited from Collection
#cursors, #next, #previous, #total_count, #unread_count, #updated_time
Instance Method Summary collapse
-
#initialize(owner, edge, params = {}, options = {}) ⇒ Edge
constructor
A new instance of Edge.
Constructor Details
#initialize(owner, edge, params = {}, options = {}) ⇒ Edge
Returns a new instance of Edge.
5 6 7 8 9 10 11 12 |
# File 'lib/fb_graph2/edge.rb', line 5 def initialize(owner, edge, params = {}, = {}) self.owner = owner self.edge = edge self.params = params self. = self.collection = .delete(:collection) || Collection.new replace collection end |
Instance Attribute Details
#collection ⇒ Object
Returns the value of attribute collection.
3 4 5 |
# File 'lib/fb_graph2/edge.rb', line 3 def collection @collection end |
#edge ⇒ Object
Returns the value of attribute edge.
3 4 5 |
# File 'lib/fb_graph2/edge.rb', line 3 def edge @edge end |
#options ⇒ Object
Returns the value of attribute options.
3 4 5 |
# File 'lib/fb_graph2/edge.rb', line 3 def end |
#owner ⇒ Object
Returns the value of attribute owner.
3 4 5 |
# File 'lib/fb_graph2/edge.rb', line 3 def owner @owner end |
#params ⇒ Object
Returns the value of attribute params.
3 4 5 |
# File 'lib/fb_graph2/edge.rb', line 3 def params @params end |